PAWpySeed: Member List

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

pawpyseed.core.projector.Projector Member List

This is the complete list of members for pawpyseed.core.projector.Projector, including all inherited members.

__init__(self, wf, basis, unsym_basis=False, unsym_wf=False, method="aug_real") | pawpyseed.core.projector.Projector |
defect_band_analysis(self, num_below_ef=20, num_above_ef=20, spinpol=False, return_energies=False, vbmband=None, band_list=None, analyze_all=False) | pawpyseed.core.projector.Projector |
make_site_lists(self) | pawpyseed.core.projector.Projector |
method | pawpyseed.core.projector.Projector |
METHODS | pawpyseed.core.projector.Projector | static
proportion_conduction(self, band_num, spinpol=False) | pawpyseed.core.projector.Projector |
setup_bases(basis_dirs, desymmetrize=True, atomate_compatible=True) | pawpyseed.core.projector.Projector | static
setup_multiple_projections(basis_dir, wf_dirs, method="aug_real", ignore_errors=False, desymmetrize=False, atomate_compatible=True) | pawpyseed.core.projector.Projector | static
setup_overlap(self) | pawpyseed.core.projector.Projector |
single_band_projection(self, band_num, kwargs) | pawpyseed.core.projector.Projector |
site_cat | pawpyseed.core.projector.Projector |